pub struct BlobCreatorProxy { /* private fields */ }Implementations
Sourceimpl BlobCreatorProxy
impl BlobCreatorProxy
Sourcepub fn take_event_stream(&self) -> BlobCreatorEventStream
pub fn take_event_stream(&self) -> BlobCreatorEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn create(
&self,
hash: &[u8; 32],
allow_existing: bool,
) -> QueryResponseFut<BlobCreatorCreateResult, FDomainResourceDialect>
pub fn create( &self, hash: &[u8; 32], allow_existing: bool, ) -> QueryResponseFut<BlobCreatorCreateResult, FDomainResourceDialect>
Creates a blob with the merkle root hash. If allow_existing is true, the server will
overwrite the existing blob if there is one. The server may fail this request with
[CreateBlobError.ALREADY_EXISTS] if there is already an inflight BlobWriter for the same
hash which has not been closed or completed. The client will truncate the blob with
[BlobWriter.GetVmo] and get a handle to a vmo in return. The client will then write blob
contents into the vmo and call [BlobWriter.BytesReady] on the ’writer` to signal to the
server that some number of bytes has been written to the vmo.
Sourcepub fn needs_overwrite(
&self,
blob_hash: &[u8; 32],
) -> QueryResponseFut<BlobCreatorNeedsOverwriteResult, FDomainResourceDialect>
pub fn needs_overwrite( &self, blob_hash: &[u8; 32], ) -> QueryResponseFut<BlobCreatorNeedsOverwriteResult, FDomainResourceDialect>
Given the hash of a blob, returns true if it should be overwritten using Create with
allow_existing set to true. Must respond the same as BlobReader.GetVmo in terms of
existence checks, responding ZX_ERR_NOT_FOUND under the same conditions.