pub struct CryptManagementProxy { /* private fields */ }Implementations
Sourceimpl CryptManagementProxy
impl CryptManagementProxy
Sourcepub fn take_event_stream(&self) -> CryptManagementEventStream
pub fn take_event_stream(&self) -> CryptManagementEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn add_wrapping_key(
&self,
wrapping_key_id: &[u8; 16],
key: &[u8],
) -> QueryResponseFut<CryptManagementAddWrappingKeyResult, FDomainResourceDialect>
pub fn add_wrapping_key( &self, wrapping_key_id: &[u8; 16], key: &[u8], ) -> QueryResponseFut<CryptManagementAddWrappingKeyResult, FDomainResourceDialect>
Adds a new wrapping key to the Crypt service. The new key will immediately be available for unwrapping keys (Crypt::UnwrapKeys) but won’t be used for wrapping keys until CryptManagement::SetActiveKeys is called.
Sourcepub fn set_active_key(
&self,
purpose: KeyPurpose,
wrapping_key_id: &[u8; 16],
) -> QueryResponseFut<CryptManagementSetActiveKeyResult, FDomainResourceDialect>
pub fn set_active_key( &self, purpose: KeyPurpose, wrapping_key_id: &[u8; 16], ) -> QueryResponseFut<CryptManagementSetActiveKeyResult, FDomainResourceDialect>
Updates the key which will be used for wrapping keys (Crypt::CreateKey). purpose
describes which active key to modify.
Sourcepub fn forget_wrapping_key(
&self,
wrapping_key_id: &[u8; 16],
) -> QueryResponseFut<CryptManagementForgetWrappingKeyResult, FDomainResourceDialect>
pub fn forget_wrapping_key( &self, wrapping_key_id: &[u8; 16], ) -> QueryResponseFut<CryptManagementForgetWrappingKeyResult, FDomainResourceDialect>
Forgets a wrapping key, preventing its use for future key-unwrapping. All future calls to Crypt::UnwrapKeys with that wrapping key ID will fail. If either the data or metadata part of the key is active, an error is returned.