pub struct CryptProxy { /* private fields */ }Implementations
Sourceimpl CryptProxy
impl CryptProxy
Sourcepub fn take_event_stream(&self) -> CryptEventStream
pub fn take_event_stream(&self) -> CryptEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn create_key(
&self,
owner: u64,
purpose: KeyPurpose,
) -> QueryResponseFut<CryptCreateKeyResult, FDomainResourceDialect>
pub fn create_key( &self, owner: u64, purpose: KeyPurpose, ) -> QueryResponseFut<CryptCreateKeyResult, FDomainResourceDialect>
Creates a new key wrapped with the key identified by wrapping_key_id. owner identifies
the owner of the key and must be supplied to UnwrapKey. The crypt service chooses a
wrapping_key_id which must be supplied to UnwrapKey. The wrapping_key_id has no
meaning to Fxfs.
TODO(https://fxbug.dev/445189846): Add an object_type field to support inline encryption.
Sourcepub fn create_key_with_id(
&self,
owner: u64,
wrapping_key_id: &[u8; 16],
object_type: ObjectType,
) -> QueryResponseFut<CryptCreateKeyWithIdResult, FDomainResourceDialect>
pub fn create_key_with_id( &self, owner: u64, wrapping_key_id: &[u8; 16], object_type: ObjectType, ) -> QueryResponseFut<CryptCreateKeyWithIdResult, FDomainResourceDialect>
Creates a new key wrapped with the key identified by wrapping_key_id. owner identifies
the owner of the key and must be supplied to UnwrapKey along with wrapping_key_id.
The wrapping_key_id has no meaning to Fxfs.
Sourcepub fn unwrap_key(
&self,
owner: u64,
wrapped_key: &WrappedKey,
) -> QueryResponseFut<CryptUnwrapKeyResult, FDomainResourceDialect>
pub fn unwrap_key( &self, owner: u64, wrapped_key: &WrappedKey, ) -> QueryResponseFut<CryptUnwrapKeyResult, FDomainResourceDialect>
Unwraps a key. owner must be the same as that passed to CreateKey.
This can fail due to permission reasons, but an incorrect key or owner will not fail;
it will just return an unwrapped key that won’t actually decrpyt the data.
ZX_ERR_UNAVAILABLE is returned if the key is known but cannot be unwrapped (e.g. it is
locked).
ZX_ERR_NOT_FOUND is returned if the key is not known. In some cases, implementations are
unable to tell the difference between the two, in which case, ZX_ERR_UNAVAILABLE is
returned.