pub struct FileBackedVolumeProviderProxy { /* private fields */ }Implementations
Sourceimpl FileBackedVolumeProviderProxy
impl FileBackedVolumeProviderProxy
Sourcepub fn new(channel: Channel) -> Self
pub fn new(channel: Channel) -> Self
Create a new Proxy for fuchsia.fxfs/FileBackedVolumeProvider.
Sourcepub fn take_event_stream(&self) -> FileBackedVolumeProviderEventStream
pub fn take_event_stream(&self) -> FileBackedVolumeProviderEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn open(
&self,
parent_directory_token: NullableHandle,
name: &str,
server_end: ServerEnd<BlockMarker>,
) -> Result<(), Error>
pub fn open( &self, parent_directory_token: NullableHandle, name: &str, server_end: ServerEnd<BlockMarker>, ) -> Result<(), Error>
Opens a file as a block device and starts serving block requests.
name must refer to an existing file in the directory represented by
parent_directory_token.
The block size of the device will match the underlying filesystem’s block size. If the file’s size is not a multiple of the block size, the apparent size of the device will be rounded down.
parent_directory_token is a token obtained via fuchsia.io.Directory/GetToken. The
directory connection must have the MODIFY_DIRECTORY right.
Errors will be sent as an epitaph on server_end.