pub struct VolumeInstallerControlHandle { /* private fields */ }Trait Implementations
Sourceimpl Clone for VolumeInstallerControlHandle
impl Clone for VolumeInstallerControlHandle
Sourcefn clone(&self) -> VolumeInstallerControlHandle
fn clone(&self) -> VolumeInstallerControlHandle
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ControlHandle for VolumeInstallerControlHandle
impl ControlHandle for VolumeInstallerControlHandle
Sourcefn shutdown(&self)
fn shutdown(&self)
Set the server to shutdown. The underlying channel is only closed the
next time the stream is polled.
Sourcefn shutdown_with_epitaph(&self, status: Status)
fn shutdown_with_epitaph(&self, status: Status)
Sets the server to shutdown with an epitaph. The underlying channel is
only closed the next time the stream is polled.
Sourcefn on_closed(&self) -> OnFDomainSignals
fn on_closed(&self) -> OnFDomainSignals
Returns a future that completes when the server receives the
PEER_CLOSED signal.Auto Trait Implementations
impl Freeze for VolumeInstallerControlHandle
impl !RefUnwindSafe for VolumeInstallerControlHandle
impl Send for VolumeInstallerControlHandle
impl Sync for VolumeInstallerControlHandle
impl Unpin for VolumeInstallerControlHandle
impl UnsafeUnpin for VolumeInstallerControlHandle
impl !UnwindSafe for VolumeInstallerControlHandle