pub struct VolumeInstallerProxy { /* private fields */ }Implementations
Sourceimpl VolumeInstallerProxy
impl VolumeInstallerProxy
Sourcepub fn take_event_stream(&self) -> VolumeInstallerEventStream
pub fn take_event_stream(&self) -> VolumeInstallerEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn install(
&self,
src: &str,
image_file: &str,
dst: &str,
) -> QueryResponseFut<VolumeInstallerInstallResult, FDomainResourceDialect>
pub fn install( &self, src: &str, image_file: &str, dst: &str, ) -> QueryResponseFut<VolumeInstallerInstallResult, FDomainResourceDialect>
Using the partition image in image_file contained in the volume src, overwrites the
volume dst with a volume of the same name from the image. On success, src will no longer
exist. There must be no objects in src other than the image that contain extents.
Neither src nor dst can be mounted or otherwise in-use.
WARNING: This will delete the existing contents of dst.