pub struct DebugProxy { /* private fields */ }Implementations
Sourceimpl DebugProxy
impl DebugProxy
Sourcepub fn take_event_stream(&self) -> DebugEventStream
pub fn take_event_stream(&self) -> DebugEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn compact(
&self,
) -> QueryResponseFut<DebugCompactResult, FDomainResourceDialect>
pub fn compact( &self, ) -> QueryResponseFut<DebugCompactResult, FDomainResourceDialect>
Forces a compaction.
Sourcepub fn delete_profile(
&self,
volume: &str,
profile: &str,
) -> QueryResponseFut<DebugDeleteProfileResult, FDomainResourceDialect>
pub fn delete_profile( &self, volume: &str, profile: &str, ) -> QueryResponseFut<DebugDeleteProfileResult, FDomainResourceDialect>
Deletes a recorded profile from a volume. Fails if the volume isn’t mounted or there is active profile recording or replay.
Sourcepub fn record_replay_profile(
&self,
volume: Option<&str>,
profile: &str,
duration_secs: u32,
) -> QueryResponseFut<DebugRecordReplayProfileResult, FDomainResourceDialect>
pub fn record_replay_profile( &self, volume: Option<&str>, profile: &str, duration_secs: u32, ) -> QueryResponseFut<DebugRecordReplayProfileResult, FDomainResourceDialect>
Begins recording a profile for a named volume for up to the given duration in seconds. If a profile already exists under the given name then it will begin replaying it as well. Fails if the volume isn’t mounted or there is active profile recording or replay on the volume.
Sourcepub fn stop_profile_tasks(
&self,
) -> QueryResponseFut<DebugStopProfileTasksResult, FDomainResourceDialect>
pub fn stop_profile_tasks( &self, ) -> QueryResponseFut<DebugStopProfileTasksResult, FDomainResourceDialect>
Stops all profile recording and replay activity. Ongoing recordings are completed and persisted.